@@ -4,20 +4,24 @@ use warnings;
 
 use List::Util qw/sum/;
 
-our $VERSION = '0.000125';
+our $VERSION = '0.000126';
 
 our @EXPORT_OK = qw/render_bench render_duration/;
 use base 'Exporter';
 
 sub render_duration {
-    my ($start, $end) = @_;
-
-    my $time = $end - $start;
+    my $time;
+    if (@_ == 1) {
+        ($time) = @_;
+    }
+    else {
+        my ($start, $end) = @_;
+        $time = $end - $start;
+    }
 
     return sprintf('%1.5fs', $time) if $time < 10;
     return sprintf('%2.4fs', $time) if $time < 60;
 
-
     my $msec  = substr(sprintf('%0.2f', $time - int($time)), -2, 2);
     my $secs  = $time % 60;
     my $mins  = int($time / 60) % 60;
